#ifndef NT2_INCLUDE_CONSTANTS_MFIVE_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MFIVE_HPP_INCLUDED

#include <nt2/constant/include/constants/mfive.hpp>

#endif
